@@ -132,20 +132,19 @@ class InterpreterClass(_instance_base.SimpleValue, class_mixin.Class):
     if self.template:
       # For function type parameters check
       for mbr in self.members.values():
-        m = abstract_utils.get_atomic_value(
-            mbr, default=self.ctx.convert.unsolvable)
-        if _isinstance(m, "SignedFunction"):
-          self.update_signature_scope(m)
-        elif mbr.data and all(
-            x.__class__.__name__ == "PropertyInstance" for x in mbr.data):
-          # We generate a new variable every time we add a property slot, so we
-          # take the last one (which contains bindings for all defined slots).
-          prop = mbr.data[-1]
-          for slot in (prop.fget, prop.fset, prop.fdel):
-            if slot:
-              for d in slot.data:
-                if _isinstance(d, "SignedFunction"):
-                  self.update_signature_scope(d)
+        prop_updated = False
+        for m in reversed(mbr.data):
+          if _isinstance(m, "SignedFunction"):
+            self.update_signature_scope(m)
+          elif not prop_updated and m.__class__.__name__ == "PropertyInstance":
+            # We generate a new variable every time we add a property slot, so
+            # take the last one (which contains bindings for all defined slots).
+            prop_updated = True
+            for slot in (m.fget, m.fset, m.fdel):
+              if slot:
+                for d in slot.data:
+                  if _isinstance(d, "SignedFunction"):
+                    self.update_signature_scope(d)
 
   def type_param_check(self):
     """Throw exception for invalid type parameters."""
@@ -809,28 +808,30 @@ class CallableClass(ParameterizedClass, mixin.HasSlots):  # pytype: disable=sign
       raise function.WrongArgCount(
           function.Signature.from_callable(self), function.Args(posargs=args),
           self.ctx)
-    formal_args = [(function.argname(i), self.formal_type_parameters[i])
-                   for i in range(self.num_args)]
-    substs = [datatypes.AliasingDict()]
-    bad_param = None
-    for view in abstract_utils.get_views(args, node):
-      arg_dict = {function.argname(i): view[args[i]]
-                  for i in range(self.num_args)}
-      subst, bad_param = self.ctx.matcher(node).compute_subst(
-          formal_args, arg_dict, view, None)
-      if subst is not None:
-        substs = [subst]
-        break
-    else:
-      if bad_param:
-        raise function.WrongArgTypes(
-            function.Signature.from_callable(self),
-            function.Args(posargs=args),
-            self.ctx,
-            bad_param=bad_param)
+    match_args = [function.Arg(function.argname(i), args[i],
+                               self.formal_type_parameters[i])
+                  for i in range(self.num_args)]
+    matcher = self.ctx.matcher(node)
+    try:
+      matches = matcher.compute_matches(match_args, match_all_views=False)
+    except matcher.MatchError as e:
+      raise function.WrongArgTypes(
+          function.Signature.from_callable(self),
+          function.Args(posargs=args),
+          self.ctx,
+          bad_param=e.bad_type)
     ret = self.ctx.annotation_utils.sub_one_annotation(
-        node, self.formal_type_parameters[abstract_utils.RET], substs)
-    node, retvar = self.ctx.vm.init_class(node, ret)
+        node, self.formal_type_parameters[abstract_utils.RET],
+        [m.subst for m in matches])
+    if args and ret.full_name == "typing.TypeGuard":
+      typeguard_return = function.handle_typeguard(
+          node, function.AbstractReturnType(ret, self.ctx), args[0], self.ctx)
+    else:
+      typeguard_return = None
+    if typeguard_return:
+      retvar = typeguard_return
+    else:
+      node, retvar = self.ctx.vm.init_class(node, ret)
     return node, retvar
 
   def get_special_attribute(self, node, name, valself):
