@@ -69,67 +69,8 @@ class Function(_instance_base.SimpleValue):
         name = self._get_cell_variable_name(a)
         assert name is not None, "Closure variable lookup failed."
         raise function.UndefinedParameterError(name)
-    # The implementation of match_args is currently rather convoluted because we
-    # have two different implementations:
-    # * Old implementation: `_match_views` matches 'args' against 'self' one
-    #   view at a time, where a view is a mapping of every variable in args to a
-    #   particular binding. This handles complex generics but scales poorly with
-    #   the number of bindings per variable.
-    # * New implementation: `_match_args_sequentially` matches 'args' one at a
-    #   time. This scales better but cannot yet handle complex generics.
-    # Subclasses should implement the following:
-    # * _match_view(node, args, view, alias_map): this will be called repeatedly
-    #   by _match_views.
-    # * _match_args_sequentially(node, args, alias_map, match_all_views): A
-    #   sequential matching implementation.
-    # TODO(b/228241343): Get rid of _match_views and simplify match_args once
-    # _match_args_sequentially can handle all generics.
-    if self._is_complex_generic_call(args):
-      return self._match_views(node, args, alias_map, match_all_views)
     return self._match_args_sequentially(node, args, alias_map, match_all_views)
 
-  def _is_complex_generic_call(self, args):
-    return False
-
-  def _match_views(self, node, args, alias_map, match_all_views):
-    """Matches all views of the given args against this function."""
-    error = None
-    matched = []
-    arg_variables = args.get_variables()
-    views = abstract_utils.get_views(arg_variables, node)
-    skip_future = None
-    while True:
-      try:
-        view = views.send(skip_future)
-      except StopIteration:
-        break
-      log.debug("args in view: %r", [(a.bindings and view[a].data)
-                                     for a in args.posargs])
-      try:
-        match = self._match_view(node, args, view, alias_map)
-      except function.FailedFunctionCall as e:
-        if not node.HasCombination(list(view.values())) or e <= error:
-          # This error was ignored, but future ones with the same accessed
-          # subset may need to be recorded, so we can't skip them.
-          skip_future = False
-        else:
-          # Add the name of the caller if possible.
-          if hasattr(self, "parent"):
-            e.name = f"{self.parent.name}.{e.name}"
-          if match_all_views or self.ctx.options.strict_parameter_checks:
-            raise e
-          error = e
-          skip_future = True
-      else:
-        matched.append(match)
-        skip_future = True
-    if not matched and error:
-      raise error  # pylint: disable=raising-bad-type
-    return matched
-
-  def _match_view(self, node, args, view, alias_map):
-    raise NotImplementedError(self.__class__.__name__)
-
   def _match_args_sequentially(self, node, args, alias_map, match_all_views):
     raise NotImplementedError(self.__class__.__name__)
 
@@ -213,7 +154,8 @@ class NativeFunction(Function):
       # ([self, ]node, ...). The length of "..." tells us how many variables
       # are expected.
       expected_argcount = len(inspect.getfullargspec(self.func).args) - 1
-      if inspect.ismethod(self.func) and self.func.__self__ is not None:
+      func = self.func
+      if inspect.ismethod(func) and func.__self__ is not None:
         expected_argcount -= 1
       actual_argcount = len(posargs) + len(namedargs)
       if (actual_argcount > expected_argcount or
@@ -245,7 +187,7 @@ class BoundFunction(_base.BaseValue):
 
   def __init__(self, callself, underlying):
     super().__init__(underlying.name, underlying.ctx)
-    self.cls = underlying.cls
+    self.cls = _classes.FunctionPyTDClass(self, self.ctx)
     self._callself = callself
     self.underlying = underlying
     self.is_attribute_of_class = False
