@@ -341,23 +341,6 @@ class PyTDFunction(_function_base.Function):
     # An opaque *args or **kwargs behaves like an unknown.
     return args.has_opaque_starargs_or_starstarargs()
 
-  def _match_view(self, node, args, view, alias_map=None):
-    if self._can_match_multiple(args):
-      signatures = tuple(self._yield_matching_signatures(
-          node, args, view, alias_map))
-    else:
-      # We take the first signature that matches, and ignore all after it.
-      # This is because in the pytds for the standard library, the last
-      # signature(s) is/are fallback(s) - e.g. list is defined by
-      # def __init__(self: x: list)
-      # def __init__(self, x: iterable)
-      # def __init__(self, x: generator)
-      # def __init__(self, x: object)
-      # with the last signature only being used if none of the others match.
-      sig = next(self._yield_matching_signatures(node, args, view, alias_map))
-      signatures = (sig,)
-    return (view, signatures)
-
   def _call_with_signatures(self, node, func, args, view, signatures):
     """Perform a function call that involves multiple signatures."""
     ret_type = self._combine_multiple_returns(signatures)
@@ -423,38 +406,6 @@ class PyTDFunction(_function_base.Function):
     ret_type = optimize.Optimize(pytd_utils.JoinTypes(options))
     return ret_type.Visit(visitors.ReplaceUnionsWithAny())
 
-  def _yield_matching_signatures(self, node, args, view, alias_map):
-    """Try, in order, all pytd signatures, yielding matches."""
-    error = None
-    matched = False
-    # Once a constant has matched a literal type, it should no longer be able to
-    # match non-literal types. For example, with:
-    #   @overload
-    #   def f(x: Literal['r']): ...
-    #   @overload
-    #   def f(x: str): ...
-    # f('r') should match only the first signature.
-    literal_matches = set()
-    for sig in self.signatures:
-      if any(not _is_literal(sig.signature.annotations.get(name))
-             for name in literal_matches):
-        continue
-      try:
-        arg_dict, substs = sig.substitute_formal_args_old(
-            node, args, view, alias_map)
-      except function.FailedFunctionCall as e:
-        if e > error:
-          error = e
-      else:
-        matched = True
-        for name, binding in arg_dict.items():
-          if (isinstance(binding.data, mixin.PythonConstant) and
-              _is_literal(sig.signature.annotations.get(name))):
-            literal_matches.add(name)
-        yield sig, arg_dict, substs
-    if not matched:
-      raise error  # pylint: disable=raising-bad-type
-
   def _match_args_sequentially(self, node, args, alias_map, match_all_views):
     error = None
     matched_signatures = _MatchedSignatures(
@@ -582,9 +533,12 @@ class PyTDSignature(utils.ContextWeakrefMixin):
     # named args
     posonly_names = set(self.signature.posonly_params)
     for name, arg in args.namedargs.items():
-      if name in arg_dict and name not in posonly_names:
+      if name in posonly_names:
+        continue
+      elif name in arg_dict:
         raise function.DuplicateKeyword(self.signature, args, self.ctx, name)
-      arg_dict[name] = arg
+      else:
+        arg_dict[name] = arg
     kws = set(args.namedargs)
     extra_kwargs = kws - {p.name for p in self.pytd_sig.params}
     if extra_kwargs and not self.pytd_sig.starstarargs:
@@ -632,28 +586,6 @@ class PyTDSignature(utils.ContextWeakrefMixin):
         # Assume the missing parameter is filled in by *args or **kwargs.
         arg_dict[p.name] = self.ctx.new_unsolvable(node)
 
-  def substitute_formal_args_old(self, node, args, view, alias_map):
-    """Substitute matching args into this signature. Used by PyTDFunction."""
-    formal_args, arg_dict = self._map_args(node, args)
-    self._fill_in_missing_parameters(node, args, arg_dict)
-    subst, bad_arg = self.ctx.matcher(node).compute_subst(
-        formal_args, arg_dict, view, alias_map)
-    if subst is None:
-      if self.signature.has_param(bad_arg.name):
-        signature = self.signature
-      else:
-        signature = self.signature.insert_varargs_and_kwargs(arg_dict)
-      raise function.WrongArgTypes(signature, args, self.ctx, bad_param=bad_arg)
-    if log.isEnabledFor(logging.DEBUG):
-      log.debug("Matched arguments against sig%s",
-                pytd_utils.Print(self.pytd_sig))
-    for nr, p in enumerate(self.pytd_sig.params):
-      log.info("param %d) %s: %s <=> %s", nr, p.name, p.type, arg_dict[p.name])
-    for name, var in sorted(subst.items()):
-      log.debug("Using %s=%r %r", name, var, var.data)
-
-    return arg_dict, [subst]
-
   def substitute_formal_args(self, node, args, match_all_views, keep_all_views):
     """Substitute matching args into this signature. Used by PyTDFunction."""
     formal_args, arg_dict = self._map_args(node, args)
@@ -677,35 +609,6 @@ class PyTDSignature(utils.ContextWeakrefMixin):
       log.info("param %d) %s: %s <=> %s", nr, p.name, p.type, arg_dict[p.name])
     return arg_dict, matches
 
-  def instantiate_return(self, node, subst, sources):
-    return_type = self.pytd_sig.return_type
-    # Type parameter values, which are instantiated by the matcher, will end up
-    # in the return value. Since the matcher does not call __init__, we need to
-    # do that now. The one exception is that Type[X] does not instantiate X, so
-    # we do not call X.__init__.
-    if return_type.name != "builtins.type":
-      for param in pytd_utils.GetTypeParameters(return_type):
-        if param.full_name in subst:
-          node = self.ctx.vm.call_init(node, subst[param.full_name])
-    try:
-      ret = self.ctx.convert.constant_to_var(
-          abstract_utils.AsReturnValue(return_type),
-          subst,
-          node,
-          source_sets=[sources])
-    except self.ctx.convert.TypeParameterError:
-      # The return type contains a type parameter without a substitution.
-      subst = abstract_utils.with_empty_substitutions(
-          subst, return_type, node, self.ctx)
-      return node, self.ctx.convert.constant_to_var(
-          abstract_utils.AsReturnValue(return_type),
-          subst,
-          node,
-          source_sets=[sources])
-    if not ret.bindings and isinstance(return_type, pytd.TypeParameter):
-      ret.AddBinding(self.ctx.convert.empty, [], node)
-    return node, ret
-
   def call_with_args(self, node, func, arg_dict, match, ret_map):
     """Call this signature. Used by PyTDFunction."""
     subst = match.subst
@@ -723,7 +626,18 @@ class PyTDSignature(utils.ContextWeakrefMixin):
       for data in ret_map[t].data:
         ret_map[t].AddBinding(data, sources, node)
     elif visible:
-      node, ret_map[t] = self.instantiate_return(node, subst, sources)
+      first_arg = self.signature.get_first_arg(arg_dict)
+      ret_type = function.PyTDReturnType(
+          self.pytd_sig.return_type, subst, sources, self.ctx)
+      if first_arg:
+        typeguard_return = function.handle_typeguard(
+            node, ret_type, first_arg, self.ctx, func_name=self.name)
+      else:
+        typeguard_return = None
+      if typeguard_return:
+        ret_map[t] = typeguard_return
+      else:
+        node, ret_map[t] = ret_type.instantiate(node)
     elif t not in ret_map:
       ret_map[t] = self.ctx.program.NewVariable()
     mutations = self._get_mutation(node, arg_dict, subst, ret_map[t])
