@@ -145,8 +145,8 @@ class Final(abstract.AnnotationClass):
 class TypingContainer(abstract.AnnotationContainer):
 
   def __init__(self, name, ctx):
-    if name in pep484.PEP484_CAPITALIZED:
-      pytd_name = "builtins." + name.lower()
+    if name in pep484.TYPING_TO_BUILTIN:
+      pytd_name = "builtins." + pep484.TYPING_TO_BUILTIN[name]
     else:
       pytd_name = "typing." + name
     base = ctx.convert.name_to_value(pytd_name)
@@ -188,6 +188,14 @@ class Callable(TypingContainer):
             ("First argument to Callable must be a list"
              " of argument types or ellipsis."))
       inner[0] = self.ctx.convert.unsolvable
+    if inner and getattr(inner[-1], "full_name", None) == "typing.TypeGuard":
+      if isinstance(inner[0], list) and len(inner[0]) < 1:
+        self.ctx.errorlog.invalid_annotation(
+            self.ctx.vm.frames, args,
+            "A TypeGuard function must have at least one required parameter")
+      if not isinstance(inner[-1], abstract.ParameterizedClass):
+        self.ctx.errorlog.invalid_annotation(
+            self.ctx.vm.frames, inner[-1], "Expected 1 parameter, got 0")
     value = self._build_value(node, tuple(inner), ellipses)
     return node, value.to_variable(node)
 
@@ -499,8 +507,8 @@ def build_final_decorator(ctx):
 _unsupported_members = {
     "Concatenate": (3, 10),
     "ParamSpec": (3, 10),
-    "TypeGuard": (3, 10),
     "is_typeddict": (3, 10),
+    "Self": (3, 11),
 }
 
 
@@ -518,6 +526,7 @@ typing_overlay = {
     "NoReturn": (build_noreturn, None),
     "Optional": (overlay.build("Optional", Optional), None),
     "Tuple": (overlay.build("Tuple", Tuple), None),
+    "TypeGuard": (_build("typing.TypeGuard"), (3, 10)),
     "TypeVar": (build_typevar, None),
     "TypedDict": (typed_dict.TypedDictBuilder, (3, 8)),
     "Union": (Union, None),
