@@ -6,14 +6,13 @@ from pytype.tests import test_base
 from pytype.tools.annotate_ast import annotate_ast
 
 
-class AnnotaterTest(test_base.TargetIndependentTest):
+class AnnotaterTest(test_base.BaseTest):
 
   def annotate(self, source):
     source = textwrap.dedent(source.lstrip('\n'))
-    ast_factory = lambda unused_options: ast
     pytype_options = config.Options.create(python_version=self.python_version)
 
-    module = annotate_ast.annotate_source(source, ast_factory, pytype_options)
+    module = annotate_ast.annotate_source(source, ast, pytype_options)
     return module
 
   def get_annotations_dict(self, module):
@@ -109,4 +108,6 @@ class AnnotaterTest(test_base.TargetIndependentTest):
     }
     self.assertEqual(expected, self.get_annotations_dict(module))
 
-test_base.main(globals(), __name__ == '__main__')
+
+if __name__ == '__main__':
+  test_base.main()
